@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Parser;
 
-our $VERSION = '0.007_001'; # TRIAL VERSION
+our $VERSION = '0.007_002'; # TRIAL VERSION
 
 use constant TRACE => $ENV{YAML_PP_TRACE} ? 1 : 0;
 use constant DEBUG => ($ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE}) ? 1 : 0;
@@ -46,7 +46,11 @@ sub set_receiver {
     $self->{callback} = $callback;
     $self->{receiver} = $receiver;
 }
-sub reader { return $_[0]->{reader} }
+sub reader { return $_[0]->lexer->{reader} }
+sub set_reader {
+    my ($self, $reader) = @_;
+    $self->lexer->set_reader($reader);
+}
 sub lexer { return $_[0]->{lexer} }
 sub callback { return $_[0]->{callback} }
 sub set_callback { $_[0]->{callback} = $_[1] }
@@ -85,12 +89,20 @@ sub init {
     $self->lexer->init;
 }
 
-sub parse {
+sub parse_string {
     my ($self, $yaml) = @_;
-    my $reader = $self->lexer->reader;
-    if (defined $yaml) {
-        $reader->set_input($yaml);
-    }
+    $self->lexer->reader->set_input( $yaml );
+    $self->parse();
+}
+
+sub parse_file {
+    my ($self, $file) = @_;
+    $self->lexer->reader->set_input( $file );
+    $self->parse();
+}
+
+sub parse {
+    my ($self) = @_;
     $self->init;
     $self->lexer->init;
     eval {
